@@ -79,8 +79,8 @@ except ImportError as error1:
 
 __Conventions__  = 'CF-1.7'
 __author__       = 'David Hassell'
-__date__         = 'Not yet released'
-__version__      = '3.0.5'
+__date__         = '2019-11-27'
+__version__      = '3.0.6'
 __cf_version__   = cfdm.core.__cf_version__
 
 from distutils.version import LooseVersion
@@ -162,7 +162,7 @@ if LooseVersion(cfunits.__version__) < LooseVersion(_minimum_vn):
             _minimum_vn, cfunits.__version__, cfunits.__file__))
 
 # Check the version of cfdm
-_minimum_vn = '1.7.10'
+_minimum_vn = '1.7.11'
 if LooseVersion(cfdm.__version__) < LooseVersion(_minimum_vn):
     raise ValueError(
         "Bad cfdm version: cf requires cfdm version {} or later. Got {} at {}".format(
