@@ -23,7 +23,7 @@ _year_units  = ('year', 'years', 'yr')
 
 class PropertiesDataBounds(PropertiesData):
     '''Mixin class for a data array with descriptive properties and cell
-bounds.
+    bounds.
 
     '''
     # Define the reserved attributes. These are methods which can't be
@@ -306,6 +306,140 @@ bounds.
         return self._binary_operation(y, '__lt__', False)
 
     
+    def __and__(self, other):
+        '''The binary bitwise operation ``&``
+
+    x.__and__(y) <==> x&y
+
+        '''
+        return self._binary_operation(other, '__and__', False)
+
+
+    def __iand__(self, other):
+        '''The augmented bitwise assignment ``&=``
+
+    x.__iand__(y) <==> x&=y
+
+        '''
+        return self._binary_operation(other, '__iand__', False)
+
+
+    def __rand__(self, other):
+        '''The binary bitwise operation ``&`` with reflected operands
+
+    x.__rand__(y) <==> y&x
+
+        '''
+        return self._binary_operation(other, '__rand__', False)
+
+
+    def __or__(self, other):
+        '''The binary bitwise operation ``|``
+
+    x.__or__(y) <==> x|y
+
+        '''
+        return self._binary_operation(other, '__or__', False)
+
+
+    def __ior__(self, other):
+        '''The augmented bitwise assignment ``|=``
+
+    x.__ior__(y) <==> x|=y
+
+        '''
+        return self._binary_operation(other, '__ior__', False)
+
+
+    def __ror__(self, other):
+        '''The binary bitwise operation ``|`` with reflected operands
+
+    x.__ror__(y) <==> y|x
+
+        '''
+        return self._binary_operation(other, '__ror__', False)
+
+    def __xor__(self, other):
+        '''The binary bitwise operation ``^``
+
+    x.__xor__(y) <==> x^y
+
+        '''
+        return self._binary_operation(other, '__xor__', False)
+
+
+    def __ixor__(self, other):
+        '''The augmented bitwise assignment ``^=``
+
+    x.__ixor__(y) <==> x^=y
+
+        '''
+        return self._binary_operation(other, '__ixor__', False)
+
+
+    def __rxor__(self, other):
+        '''The binary bitwise operation ``^`` with reflected operands
+
+    x.__rxor__(y) <==> y^x
+
+        '''
+        return self._binary_operation(other, '__rxor__', False)
+
+
+    def __lshift__(self, y):
+        '''The binary bitwise operation ``<<``
+
+    x.__lshift__(y) <==> x<<y
+
+        '''
+        return self._binary_operation(y, '__lshift__', False)
+
+
+    def __ilshift__(self, y):
+        '''The augmented bitwise assignment ``<<=``
+
+    x.__ilshift__(y) <==> x<<=y
+
+        '''
+        return self._binary_operation(y, '__ilshift__', False)
+
+
+    def __rlshift__(self, y):
+        '''The binary bitwise operation ``<<`` with reflected operands
+
+    x.__rlshift__(y) <==> y<<x
+
+        '''
+        return self._binary_operation(y, '__rlshift__', False)
+
+
+    def __rshift__(self, y):
+        '''The binary bitwise operation ``>>``
+
+    x.__lshift__(y) <==> x>>y
+
+        '''
+        return self._binary_operation(y, '__rshift__', False)
+
+    
+    def __irshift__(self, y):
+        '''The augmented bitwise assignment ``>>=``
+
+    x.__irshift__(y) <==> x>>=y
+
+        '''
+        return self._binary_operation(y, '__irshift__', False)
+
+
+    def __rrshift__(self, y):
+        '''The binary bitwise operation ``>>`` with reflected operands
+
+    x.__rrshift__(y) <==> y>>x
+
+        '''
+        return self._binary_operation(y, '__rrshift__', False)
+
+
     # ----------------------------------------------------------------
     # Private methods
     # ----------------------------------------------------------------
@@ -349,11 +483,20 @@ bounds.
         new = super()._binary_operation(other, method)
 
         if has_bounds:
+#            try:
+#                other_has_bounds = other.has_bounds()
+#            except AttributeError:
+#                other_has_bounds = False
+
+#            if other_has_bounds:
+#                new_bounds = self.bounds._binary_operation(other.bounds, method)
+#            else:                
             if numpy_size(other) > 1:
                 try:
                     other = other.insert_dimension(-1)
                 except AttributeError:
                     other = numpy_expand_dims(other, -1)
+            #-- End: if
                 
             new_bounds = self.bounds._binary_operation(other, method)
 
@@ -370,53 +513,6 @@ bounds.
             return new
 
 
-#    def _change_axis_names(self, dim_name_map):
-#        '''
-#
-#Change the axis names.
-#
-#Warning: dim_name_map may be changed in place
-#
-#:Parameters:
-#
-#    dim_name_map : dict
-#
-#:Returns:
-#
-#    None
-#
-#**Examples:**
-#
-#'''
-#        # Change the axis names of the data array
-#        super()._change_axis_names(dim_name_map)
-#
-#        bounds = self.get_bounds(None)
-#        bounds_data = bounds.get_data(None)
-#        if bounds_data is not None:
-#            b_axes = bounds_data._axes # TODO
-#            data = self.get_data(None)
-#            if data is not None:
-#                # Change the dimension names of the bounds
-#                # array. Note that it is assumed that the bounds
-#                # array dimensions are in the same order as the
-#                # variable's data array dimensions. It is not
-#                # required that the set of original bounds
-#                # dimension names (bar the trailing dimension)
-#                # equals the set of original variable's data array
-#                # dimension names. The bounds array dimension
-#                # names will be changed to match the updated
-#                # variable's data array dimension names.
-#                dim_name_map = {b_axes[-1]: 'bounds'}
-#                for c_dim, b_dim in zip(data._axes, b_axes):
-#                     dim_name_map[b_dim] = c_dim
-#            else:
-#                dim_name_map[b_axes[-1]] = 'bounds'
-#
-#            bounds._change_axis_names(dim_name_map)
-#    #--- End: def
-
-
     def _equivalent_data(self, other, rtol=None, atol=None,
                          verbose=False):
         '''TODO
@@ -518,9 +614,14 @@ bounds.
 
         '''
         data = self.get_bounds_data(None)
-        if data is not None:            
-            out = abs(data[:, 1] - data[:, 0])
-            out.squeeze(1, inplace=True)
+        if data is not None:
+            if data.shape[-1] != 2:
+                raise ValueError(
+                    "Can only calculate cell sizes from bounds when there are exactly two bounds per cell. Got {}".format(
+                        data.shape[-1]))
+            
+            out = abs(data[..., 1] - data[..., 0])
+            out.squeeze(-1, inplace=True)                
             return out
         else:
             data = self.get_data(None)
@@ -813,58 +914,60 @@ dtype('float64')
                 return bounds.dtype
             
             raise AttributeError(error)
-    #--- End: def
+
     @dtype.setter
     def dtype(self, value):
-# DCH - allow dtype to be set before data c.f.  Units
+        # DCH - allow dtype to be set before data c.f.  Units
         data = self.get_data(None)
         if data is not None:
             self.Data.dtype = value
-    #--- End: def
+
     @dtype.deleter
     def dtype(self):
         data = self.get_data(None)
         if data is not None:
             del self.Data.dtype
-    #--- End: def
 
-    # 1
+
+    # ----------------------------------------------------------------
+    # Methods
+    # ----------------------------------------------------------------
     def ceil(self, bounds=True, inplace=False, i=False):
         '''The ceiling of the data, element-wise.
 
-The ceiling of ``x`` is the smallest integer ``n``, such that ``n >=
-x``.
-
-.. versionadded:: 1.0
-
-.. seealso:: `floor`, `rint`, `trunc`
-
-:Parameters:
-
-    bounds: `bool`, optional
-        If False then do not alter any bounds. By default any bounds
-        are also altered.
-
-    inplace: `bool`, optional
-        If True then do the operation in-place and return `None`.
-
-    i: deprecated at version 3.0.0
-        Use *inplace* parameter instead.
-
-:Returns:
-
-        The construct with ceilinged of data. If the operation was
-        in-place then `None` is returned.
-
-**Examples:**
-
->>> print(f.array)
-[-1.9 -1.5 -1.1 -1.   0.   1.   1.1  1.5  1.9]
->>> print(f.ceil().array)
-[-1. -1. -1. -1.  0.  1.  2.  2.  2.]
->>> f.ceil(inplace=True)
->>> print(f.array)
-[-1. -1. -1. -1.  0.  1.  2.  2.  2.]
+    The ceiling of ``x`` is the smallest integer ``n``, such that
+     ``n >= x``.
+    
+    .. versionadded:: 1.0
+    
+    .. seealso:: `floor`, `rint`, `trunc`
+    
+    :Parameters:
+    
+        bounds: `bool`, optional
+            If False then do not alter any bounds. By default any
+            bounds are also altered.
+    
+        inplace: `bool`, optional
+            If True then do the operation in-place and return `None`.
+    
+        i: deprecated at version 3.0.0
+            Use *inplace* parameter instead.
+    
+    :Returns:
+    
+            The construct with ceilinged of data. If the operation was
+            in-place then `None` is returned.
+    
+    **Examples:**
+    
+    >>> print(f.array)
+    [-1.9 -1.5 -1.1 -1.   0.   1.   1.1  1.5  1.9]
+    >>> print(f.ceil().array)
+    [-1. -1. -1. -1.  0.  1.  2.  2.  2.]
+    >>> f.ceil(inplace=True)
+    >>> print(f.array)
+    [-1. -1. -1. -1.  0.  1.  2.  2.  2.]
 
         '''
         if i:
@@ -878,16 +981,13 @@ x``.
             bounds = v.get_bounds(None)
             if bounds is not None:
                 bounds.ceil(inplace=True)
-        #--- End: def
+        #--- End: if
 
         if inplace:
             v = None
         return v
-    #--- End: def
 
-    # ----------------------------------------------------------------
-    # Methods
-    # ----------------------------------------------------------------
+
     def chunk(self, chunksize=None):
         '''Partition the data array.
 
@@ -972,29 +1072,28 @@ x``.
             bounds = v.get_bounds(None)
             if bounds is not None:
                 bounds.clip(a_min, a_max, units=units, inplace=True)
-        #--- End: def
+        #--- End: if
 
         if inplace:
             v = None
         return v
 
     
-    # 0
     def close(self):
         '''Close all files referenced by the construct.
 
-Note that a closed file will be automatically reopened if its contents
-are subsequently required.
-
-.. seealso:: `files`
-
-:Returns:
-
-    `None`
-
-**Examples:**
-
->> c.close()
+    Note that a closed file will be automatically re-opened if its
+    contents are subsequently required.
+    
+    .. seealso:: `files`
+    
+    :Returns:
+    
+        `None`
+    
+    **Examples:**
+    
+    >> c.close()
 
         '''
         super().close()
@@ -1002,22 +1101,21 @@ are subsequently required.
         bounds = self.get_bounds(None)
         if bounds is not None:
             bounds.close()
-    #--- End: def
 
-    # 0
+
     @classmethod
     def concatenate(cls, variables, axis=0, _preserve=True):
         '''Join a sequence of variables together.
-
-:Parameters:
-
-    variables: sequence of constructs
-
-    axis: `int`, optional
-
-:Returns:
-
-TODO
+    
+    :Parameters:
+    
+        variables: sequence of constructs
+    
+        axis: `int`, optional
+    
+    :Returns:
+    
+    TODO
         '''
         variable0 = variables[0]
 
@@ -1034,59 +1132,58 @@ TODO
             out.set_bounds(bounds, copy=False)
 
         return out
-    #--- End: def
 
-    # 1
+
     def cos(self, bounds=True, inplace=False,  i=False):
         '''Take the trigonometric cosine of the data, element-wise.
 
-Units are accounted for in the calculation, so that the the cosine of
-90 degrees_east is 0.0, as is the cosine of 1.57079632 radians. If the
-units are not equivalent to radians (such as Kelvin) then they are
-treated as if they were radians.
-
-The output units are '1' (nondimensionsal).
-
-.. seealso:: `sin`, `tan`
-
-:Parameters:
-
-    bounds: `bool`, optional
-        If False then do not alter any bounds. By default any bounds
-        are also altered.
-
-    inplace: `bool`, optional
-        If True then do the operation in-place and return `None`.
-
-    i: deprecated at version 3.0.0
-        Use *inplace* parameter instead.
-
-:Returns:
-
-        The construct with the cosine of data values. If the
-        operation was in-place then `None` is returned.
-
-**Examples:**
-
->>> f.Units
-<Units: degrees_east>
->>> print(f.array)
-[[-90 0 90 --]]
->>> f.cos()
->>> f.Units
-<Units: 1>
->>> print(f.array)
-[[0.0 1.0 0.0 --]]
-
->>> f.Units
-<Units: m s-1>
->>> print(f.array)
-[[1 2 3 --]]
->>> f.cos()
->>> f.Units
-<Units: 1>
->>> print(f.array)
-[[0.540302305868 -0.416146836547 -0.9899924966 --]]
+    Units are accounted for in the calculation, so that the the cosine
+    of 90 degrees_east is 0.0, as is the cosine of 1.57079632
+    radians. If the units are not equivalent to radians (such as
+    Kelvin) then they are treated as if they were radians.
+    
+    The output units are '1' (nondimensionsal).
+    
+    .. seealso:: `sin`, `tan`
+    
+    :Parameters:
+    
+        bounds: `bool`, optional
+            If False then do not alter any bounds. By default any
+            bounds are also altered.
+    
+        inplace: `bool`, optional
+            If True then do the operation in-place and return `None`.
+    
+        i: deprecated at version 3.0.0
+            Use *inplace* parameter instead.
+    
+    :Returns:
+    
+            The construct with the cosine of data values. If the
+            operation was in-place then `None` is returned.
+    
+    **Examples:**
+    
+    >>> f.Units
+    <Units: degrees_east>
+    >>> print(f.array)
+    [[-90 0 90 --]]
+    >>> f.cos()
+    >>> f.Units
+    <Units: 1>
+    >>> print(f.array)
+    [[0.0 1.0 0.0 --]]
+    
+    >>> f.Units
+    <Units: m s-1>
+    >>> print(f.array)
+    [[1 2 3 --]]
+    >>> f.cos()
+    >>> f.Units
+    <Units: 1>
+    >>> print(f.array)
+    [[0.540302305868 -0.416146836547 -0.9899924966 --]]
 
         '''
         if i:
@@ -1105,9 +1202,8 @@ The output units are '1' (nondimensionsal).
         if inplace:
             v = None
         return v
-    #--- End: def
 
-    # 1
+
     def cyclic(self, axes=None, iscyclic=True):
         '''Set the cyclicity of axes of the data array.
 
@@ -1568,17 +1664,19 @@ The output units are '1' (nondimensionsal).
     def match_by_property(self, *mode, **properties):
         '''Determine whether or not a variable satisfies conditions.
 
-Conditions may be specified on the variable's attributes and CF
-properties.
+    Conditions may be specified on the variable's attributes and CF
+    properties.
+    
+    :Parameters:
+     
+    :Returns:
+    
+        out: `bool`
+            Whether or not the variable matches the given criteria.
+    
+    **Examples:**
 
-:Parameters:
- 
-:Returns:
-
-    out: `bool`
-        Whether or not the variable matches the given criteria.
-
-**Examples:**
+    TODO
 
         '''
         _or = False
@@ -1612,7 +1710,7 @@ properties.
         #--- End: for
 
         return ok
-    #--- End: def
+
 
     def match_by_identity(self, *identities):
         '''Determine whether or not a variable satisfies conditions.
@@ -1871,45 +1969,44 @@ properties.
         return v
 
 
-    # 1
     def exp(self, bounds=True, inplace=False, i=False):
         '''The exponential of the data, element-wise.
 
-.. seealso:: `log`
-
-:Parameters:
-
-    bounds: `bool`, optional
-        If False then do not alter any bounds. By default any bounds
-        are also altered.
-
-    inplace: `bool`, optional
-        If True then do the operation in-place and return `None`.
-
-    i: deprecated at version 3.0.0
-        Use *inplace* parameter instead.
-
-:Returns:
-
-        The construct with the exponential of data values. If the
-        operation was in-place then `None` is returned.
-
-**Examples:**
-
->>> f.data
-<CF Data(1, 2): [[1, 2]]>
->>> f.exp().data            
-<CF Data(1, 2): [[2.71828182846, 7.38905609893]]>
-
->>> f.data
-<CF Data(1, 2): [[1, 2]] 2>
->>> f.exp().data            
-<CF Data(1, 2): [[7.38905609893, 54.5981500331]]>
-
->>> f.data
-<CF Data(1, 2): [[1, 2]] kg m-1 s-2>
->>> f.exp()          
-ValueError: Can't take exponential of dimensional quantities: <Units: kg m-1 s-2>
+    .. seealso:: `log`
+    
+    :Parameters:
+    
+        bounds: `bool`, optional
+            If False then do not alter any bounds. By default any
+            bounds are also altered.
+    
+        inplace: `bool`, optional
+            If True then do the operation in-place and return `None`.
+    
+        i: deprecated at version 3.0.0
+            Use *inplace* parameter instead.
+    
+    :Returns:
+    
+            The construct with the exponential of data values. If the
+            operation was in-place then `None` is returned.
+    
+    **Examples:**
+    
+    >>> f.data
+    <CF Data(1, 2): [[1, 2]]>
+    >>> f.exp().data            
+    <CF Data(1, 2): [[2.71828182846, 7.38905609893]]>
+    
+    >>> f.data
+    <CF Data(1, 2): [[1, 2]] 2>
+    >>> f.exp().data            
+    <CF Data(1, 2): [[7.38905609893, 54.5981500331]]>
+    
+    >>> f.data
+    <CF Data(1, 2): [[1, 2]] kg m-1 s-2>
+    >>> f.exp()          
+    ValueError: Can't take exponential of dimensional quantities: <Units: kg m-1 s-2>
 
         '''
         if i:
@@ -1928,47 +2025,46 @@ ValueError: Can't take exponential of dimensional quantities: <Units: kg m-1 s-2
         if inplace:
             v = None
         return v
-    #--- End: def
 
-    # 0
+
     def set_bounds(self, bounds, copy=True):
         '''Set the bounds.
 
-.. versionadded:: 1.7.0
-
-.. seealso: `del_bounds`, `get_bounds`, `has_bounds`, `set_data`
-
-:Parameters:
-
-    bounds: `Bounds`
-        The bounds to be inserted.
-
-    copy: `bool`, optional
-        If False then do not copy the bounds prior to insertion. By
-        default the bounds are copied.
-
-:Returns:
-
-    `None`
-
-**Examples:**
-
->>> import numpy
->>> b = cfdm.Bounds(data=cfdm.Data(numpy.arange(10).reshape(5, 2)))
->>> c.set_bounds(b)
->>> c.has_bounds()
-True
->>> c.get_bounds()
-<Bounds: (5, 2) >
->>> b = c.del_bounds()
->>> b
-<Bounds: (5, 2) >
->>> c.has_bounds()
-False
->>> print(c.get_bounds(None))
-None
->>> print(c.del_bounds(None))
-None
+    .. versionadded:: 3.0.0
+    
+    .. seealso: `del_bounds`, `get_bounds`, `has_bounds`, `set_data`
+    
+    :Parameters:
+    
+        bounds: `Bounds`
+            The bounds to be inserted.
+    
+        copy: `bool`, optional
+            If False then do not copy the bounds prior to
+            insertion. By default the bounds are copied.
+    
+    :Returns:
+    
+        `None`
+    
+    **Examples:**
+    
+    >>> import numpy
+    >>> b = cfdm.Bounds(data=cfdm.Data(numpy.arange(10).reshape(5, 2)))
+    >>> c.set_bounds(b)
+    >>> c.has_bounds()
+    True
+    >>> c.get_bounds()
+    <Bounds: (5, 2) >
+    >>> b = c.del_bounds()
+    >>> b
+    <Bounds: (5, 2) >
+    >>> c.has_bounds()
+    False
+    >>> print(c.get_bounds(None))
+    None
+    >>> print(c.del_bounds(None))
+    None
 
         '''
         data = self.get_data(None)
@@ -2006,59 +2102,58 @@ None
         self._custom['direction'] = None
         
         super().set_bounds(bounds, copy=False)
-    #--- End: def
 
-    # 1
+
     def sin(self, bounds=True, inplace=False, i=False):
         '''The trigonometric sine of the data, element-wise.
 
-Units are accounted for in the calculation. For example, the the sine
-of 90 degrees_east is 1.0, as is the sine of 1.57079632 radians. If
-the units are not equivalent to radians (such as Kelvin) then they are
-treated as if they were radians.
-
-The Units are changed to '1' (nondimensionsal).
-
-.. seealso:: `cos`, `tan`
-
-:Parameters:
-
-    bounds: `bool`, optional
-        If False then do not alter any bounds. By default any bounds
-        are also altered.
-
-    inplace: `bool`, optional
-        If True then do the operation in-place and return `None`.
-
-    i: deprecated at version 3.0.0
-        Use *inplace* parameter instead.
-
-:Returns:
-
-        The construct with the sine of data values. If the
-        operation was in-place then `None` is returned.
-
-**Examples:**
-
->>> f.Units
-<Units: degrees_north>
->>> print(f.array)
-[[-90 0 90 --]]
->>> f.sin()
->>> f.Units
-<Units: 1>
->>> print(f.array)
-[[-1.0 0.0 1.0 --]]
-
->>> f.Units
-<Units: m s-1>
->>> print f.array
-[[1 2 3 --]]
->>> f.sin()
->>> f.Units
-<Units: 1>
->>> print(f.array)
-[[0.841470984808 0.909297426826 0.14112000806 --]]
+    Units are accounted for in the calculation. For example, the the
+    sine of 90 degrees_east is 1.0, as is the sine of 1.57079632
+    radians. If the units are not equivalent to radians (such as
+    Kelvin) then they are treated as if they were radians.
+    
+    The Units are changed to '1' (nondimensionsal).
+    
+    .. seealso:: `cos`, `tan`
+    
+    :Parameters:
+    
+        bounds: `bool`, optional
+            If False then do not alter any bounds. By default any
+            bounds are also altered.
+    
+        inplace: `bool`, optional
+            If True then do the operation in-place and return `None`.
+    
+        i: deprecated at version 3.0.0
+            Use *inplace* parameter instead.
+    
+    :Returns:
+    
+            The construct with the sine of data values. If the
+            operation was in-place then `None` is returned.
+    
+    **Examples:**
+    
+    >>> f.Units
+    <Units: degrees_north>
+    >>> print(f.array)
+    [[-90 0 90 --]]
+    >>> f.sin()
+    >>> f.Units
+    <Units: 1>
+    >>> print(f.array)
+    [[-1.0 0.0 1.0 --]]
+    
+    >>> f.Units
+    <Units: m s-1>
+    >>> print f.array
+    [[1 2 3 --]]
+    >>> f.sin()
+    >>> f.Units
+    <Units: 1>
+    >>> print(f.array)
+    [[0.841470984808 0.909297426826 0.14112000806 --]]
 
         '''
         if i:
@@ -2077,41 +2172,42 @@ The Units are changed to '1' (nondimensionsal).
         if inplace:
             v = None            
         return v
-    #--- End: def
 
-    # 0
+
     def tan(self, bounds=True, inplace=False, i=False):
         '''The trigonometric tangent of the data, element-wise.
 
-Units are accounted for in the calculation, so that the the tangent of
-180 degrees_east is 0.0, as is the sine of 3.141592653589793
-radians. If the units are not equivalent to radians (such as Kelvin)
-then they are treated as if they were radians.
+    Units are accounted for in the calculation, so that the the
+    tangent of 180 degrees_east is 0.0, as is the sine of
+    3.141592653589793 radians. If the units are not equivalent to
+    radians (such as Kelvin) then they are treated as if they were
+    radians.
+    
+    The Units are changed to '1' (nondimensionsal).
+    
+    .. seealso:: `cos`, `sin`
+    
+    :Parameters:
+    
+        bounds: `bool`, optional
+            If False then do not alter any bounds. By default any
+            bounds are also altered.
+    
+        inplace: `bool`, optional
+            If True then do the operation in-place and return `None`.
+    
+        i: deprecated at version 3.0.0
+            Use *inplace* parameter instead.
+    
+    :Returns:
+            
+            The construct with the tangent of data values. If the
+            operation was in-place then `None` is returned.
+    
+    **Examples:**
+    
+    TODO
 
-The Units are changed to '1' (nondimensionsal).
-
-.. seealso:: `cos`, `sin`
-
-:Parameters:
-
-    bounds: `bool`, optional
-        If False then do not alter any bounds. By default any bounds
-        are also altered.
-
-    inplace: `bool`, optional
-        If True then do the operation in-place and return `None`.
-
-    i: deprecated at version 3.0.0
-        Use *inplace* parameter instead.
-
-:Returns:
-        
-        The construct with the tangent of data values. If the
-        operation was in-place then `None` is returned.
-
-**Examples:**
-
-TODO
         '''
         if i:
             _DEPRECATION_ERROR_KWARGS(self, 'tan', i=True) # pragma: no cover  
@@ -2130,61 +2226,60 @@ TODO
             v = None
             
         return v
-    #--- End: def
 
-    # 1
+
     def log(self, base=None, bounds=True, inplace=False, i=False):
         '''The logarithm of the data array.
 
-By default the natural logarithm is taken, but any base may be
-specified.
-
-.. seealso:: `exp`
-
-:Parameters:
-
-    base: number, optional
-        The base of the logiarthm. By default a natural logiarithm is
-        taken.
-
-    bounds: `bool`, optional
-        If False then do not alter any bounds. By default any bounds
-        are also altered.
-
-    inplace: `bool`, optional
-        If True then do the operation in-place and return `None`.
-
-    i: deprecated at version 3.0.0
-        Use *inplace* parameter instead.
-
-:Returns:
-
-        The construct with the logarithm of data values. If the
-        operation was in-place then `None` is returned.
-
-**Examples:**
-
->>> f.data
-<CF Data(1, 2): [[1, 2]]>
->>> f.log().data
-<CF Data: [[0.0, 0.69314718056]] ln(re 1)>
-
->>> f.data
-<CF Data(1, 2): [[1, 2]] 2>
->>> f.log().data
-<CF Data(1, 2): [[0.0, 0.69314718056]] ln(re 2 1)>
-
->>> f.data
-<CF Data(1, 2): [[1, 2]] kg s-1 m-2>
->>> f.log().data
-<CF Data(1, 2): [[0.0, 0.69314718056]] ln(re 1 m-2.kg.s-1)>
-
->>> f.log(inplace=True)
-
->>> f.Units
-<Units: >
->>> f.log()
-ValueError: Can't take the logarithm to the base 2.718281828459045 of <Units: >
+    By default the natural logarithm is taken, but any base may be
+    specified.
+    
+    .. seealso:: `exp`
+    
+    :Parameters:
+    
+        base: number, optional
+            The base of the logiarthm. By default a natural logiarithm
+            is taken.
+    
+        bounds: `bool`, optional
+            If False then do not alter any bounds. By default any
+            bounds are also altered.
+    
+        inplace: `bool`, optional
+            If True then do the operation in-place and return `None`.
+    
+        i: deprecated at version 3.0.0
+            Use *inplace* parameter instead.
+    
+    :Returns:
+    
+            The construct with the logarithm of data values. If the
+            operation was in-place then `None` is returned.
+    
+    **Examples:**
+    
+    >>> f.data
+    <CF Data(1, 2): [[1, 2]]>
+    >>> f.log().data
+    <CF Data: [[0.0, 0.69314718056]] ln(re 1)>
+    
+    >>> f.data
+    <CF Data(1, 2): [[1, 2]] 2>
+    >>> f.log().data
+    <CF Data(1, 2): [[0.0, 0.69314718056]] ln(re 2 1)>
+    
+    >>> f.data
+    <CF Data(1, 2): [[1, 2]] kg s-1 m-2>
+    >>> f.log().data
+    <CF Data(1, 2): [[0.0, 0.69314718056]] ln(re 1 m-2.kg.s-1)>
+    
+    >>> f.log(inplace=True)
+    
+    >>> f.Units
+    <Units: >
+    >>> f.log()
+    ValueError: Can't take the logarithm to the base 2.718281828459045 of <Units: >
 
         '''
         if i:
@@ -2203,7 +2298,6 @@ ValueError: Can't take the logarithm to the base 2.718281828459045 of <Units: >
         if inplace:
             v = None    
         return v
-    #--- End: def
 
 
     def squeeze(self, axes=None, inplace=False, i=False):
@@ -2288,7 +2382,7 @@ ValueError: Can't take the logarithm to the base 2.718281828459045 of <Units: >
 
         '''
         if i:
-            _DEPRECATION_ERROR_KWARGS(self, 'trunc', i=True) # pragma: no cover                    
+            _DEPRECATION_ERROR_KWARGS(self, 'trunc', i=True) # pragma: no cover
 
         v = super().trunc(inplace=inplace)
         if inplace:
@@ -2451,7 +2545,8 @@ ValueError: Can't take the logarithm to the base 2.718281828459045 of <Units: >
 
         '''
         if relaxed_identity:
-            _DEPRECATAION_ERROR_KWARGS(self, 'identity', relaxed_identity=True) # pragma: no cover
+            _DEPRECATAION_ERROR_KWARGS(
+                self, 'identity', relaxed_identity=True) # pragma: no cover
             
         identity = super().identity(default=None, strict=strict,
                                     relaxed=relaxed, nc_only=nc_only)
