@@ -23,8 +23,12 @@ class FieldTest(unittest.TestCase):
                                       'test_file2.nc')
         self.contiguous = os.path.join(os.path.dirname(os.path.abspath(__file__)),
                                        'DSG_timeSeries_contiguous.nc')
+        self.indexed = os.path.join(os.path.dirname(os.path.abspath(__file__)),
+                                    'DSG_timeSeries_indexed.nc')
+        self.indexed_contiguous = os.path.join(os.path.dirname(os.path.abspath(__file__)),
+                                               'DSG_timeSeriesProfile_indexed_contiguous.nc')
         
-        self.chunk_sizes = (17, 34, 300, 100000)[::-1]
+        self.chunk_sizes = (100000, 300, 34, 17)
         self.original_chunksize = cf.CHUNKSIZE()
         self.atol = cf.ATOL()
         self.rtol = cf.RTOL()
@@ -50,8 +54,8 @@ class FieldTest(unittest.TestCase):
 #        self.test_only = ['test_Field_section']
 #        self.test_only = ['test_Field_flip']
 #        self.test_only = ['test_Field_Field_domain_mask']
-#        self.test_only = ['test_Field_bin']
-
+#        self.test_only = ['test_Field_compress_uncompress']
+#        self.test_only = ['test_Field_coordinate_reference']
         
     def test_Field_creation_commands(self):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
@@ -82,6 +86,51 @@ class FieldTest(unittest.TestCase):
         #--- End: for
             
         
+    def test_Field_compress_uncompress(self):
+        if self.test_only and inspect.stack()[0][3] not in self.test_only:
+            return
+
+        methods = ('contiguous', 'indexed', 'indexed_contiguous')
+        
+        for method in methods:
+            message = 'method='+method
+            for f in cf.read(getattr(self, method)):
+
+                self.assertTrue(bool(f.data.get_compression_type()), message)
+
+                u = f.uncompress()
+                self.assertFalse(bool(u.data.get_compression_type()), message)
+                self.assertTrue(f.equals(u, verbose=True), message)
+
+                for method1 in methods:
+                    message += ', method1='+method1
+                    if method1 == 'indexed_contiguous':
+                        if f.ndim != 3:
+                            continue
+                    elif f.ndim != 2:
+                        continue
+                    
+#                    print(method, method1, f.ndim)
+                    c = u.compress(method1)
+                    self.assertTrue(bool(c.data.get_compression_type()), message)
+
+                    self.assertTrue(u.equals(c, verbose=True), message)
+                    self.assertTrue(f.equals(c, verbose=True), message)
+                    
+                    c = f.compress(method1)
+                    self.assertTrue(bool(c.data.get_compression_type()), message)
+                
+                    self.assertTrue(u.equals(c, verbose=True), message)
+                    self.assertTrue(f.equals(c, verbose=True), message)
+
+                    cf.write(c, 'delme.nc')
+                    c = cf.read('delme.nc')[0]
+
+                    self.assertTrue(bool(c.data.get_compression_type()), message)
+                    self.assertTrue(f.equals(c, verbose=True), message)
+        #--- End: for
+        
+        
     def test_Field_flatten(self):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
@@ -473,17 +522,21 @@ class FieldTest(unittest.TestCase):
         
         query1 = cf.wi(1, 5) & cf.ne(4)
 
-        for chunksize in self.chunk_sizes:
+        for chunksize in self.chunk_sizes[0:2]:
             cf.CHUNKSIZE(chunksize)
-            f = cf.read(self.contiguous)[0]
-            
+
+            f = cf.read(self.contiguous, verbose=False)[0]
+
             for (method, shape, a) in zip(['compress', 'envelope', 'full'],
                                           [ac.shape, ae.shape, af.shape],
                                           [ac, ae, af]):
                 message = 'method={!r}'.format(method)
+
+                i = f.indices(method, time=query1)
+
                 g = f.subspace(method, time=query1)
                 t = g.coordinate('time')
-                
+
                 self.assertTrue(g.shape == shape, message)
                 self.assertTrue(t.shape == shape, message)
 
@@ -507,7 +560,7 @@ class FieldTest(unittest.TestCase):
         ae2 = numpy.ma.where((ae==1)| (ae==3) | (ae==5), ae, numpy.ma.masked)
         af2 = numpy.ma.where((af==1)| (af==3) | (af==5), af, numpy.ma.masked)
 
-        for chunksize in self.chunk_sizes:
+        for chunksize in self.chunk_sizes[0:2]:
             cf.CHUNKSIZE(chunksize)
             f = cf.read(self.contiguous)[0]
             
@@ -548,7 +601,7 @@ class FieldTest(unittest.TestCase):
         
         query3 = cf.set([-2, 3, 4])
 
-        for chunksize in self.chunk_sizes:
+        for chunksize in self.chunk_sizes[0:2]:
             cf.CHUNKSIZE(chunksize)
             f = cf.read(self.contiguous)[0].subspace[[0, 2, 3], 1:]
             
@@ -734,36 +787,32 @@ class FieldTest(unittest.TestCase):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
 
-        for chunksize in self.chunk_sizes:
-            cf.CHUNKSIZE(chunksize)
-            f = cf.read(self.filename)[0]
+        f = cf.read(self.filename)[0]
 
-            g = f.copy()
-            h = g.cumsum(2)
-            self.assertTrue(g.cumsum(2, inplace=True) is None)
-            self.assertTrue(g.equals(h, verbose=True))
+        g = f.copy()
+        h = g.cumsum(2)
+        self.assertTrue(g.cumsum(2, inplace=True) is None)
+        self.assertTrue(g.equals(h, verbose=True))
 
-            for i in range(f.ndim):
-                a = numpy.cumsum(f.array, axis=i)
-                self.assertTrue((f.cumsum(i).array == a).all())
-                
-            f[0, 0, 3] = cf.masked
-            f[0, 2, 7] = cf.masked
+        for i in range(f.ndim):
+            a = numpy.cumsum(f.array, axis=i)
+            self.assertTrue((f.cumsum(i).array == a).all())
             
-            for i in range(f.ndim):
-                a = f.array
-                a = numpy.cumsum(a, axis=i)
-                g = f.cumsum(i)
-                self.assertTrue(cf.functions._numpy_allclose(g.array, a))
+        f[0, 0, 3] = cf.masked
+        f[0, 2, 7] = cf.masked
+        
+        for i in range(f.ndim):
+            a = f.array
+            a = numpy.cumsum(a, axis=i)
+            g = f.cumsum(i)
+            self.assertTrue(cf.functions._numpy_allclose(g.array, a))
 
-            for i in range(f.ndim):
-                a = f.array
-                a = a.filled(0)
-                a = numpy.cumsum(a, axis=i)
-                g = f.cumsum(i, masked_as_zero=True)
-                self.assertTrue(cf.functions._numpy_allclose(g.array, a))
-        #--- End: for
-        cf.CHUNKSIZE(self.original_chunksize)
+        for i in range(f.ndim):
+            a = f.array
+            a = a.filled(0)
+            a = numpy.cumsum(a, axis=i)
+            g = f.cumsum(i, masked_as_zero=True)
+            self.assertTrue(cf.functions._numpy_allclose(g.array, a))
 
         
     def test_Field_flip(self):
