@@ -1,6 +1,7 @@
 import atexit
 import datetime
 import unittest
+import inspect
 
 import cf
 
@@ -18,7 +19,10 @@ class functionTest(unittest.TestCase):
             a = f.array
             d = f.dump(display=False)
             
+        with self.assertRaises(Exception):
+            _ = cf.example_field(-999)
 
+            
 #--- End: class
 
 if __name__ == '__main__':
