@@ -7,41 +7,40 @@ import numpy
 from . import cInterface
 from .extraData import ExtraDataUnpacker
 
+
 class UMFileException(Exception):
     pass
 
+
 class File:
     '''A class for a UM data file that gives a view of the file including
-sets of PP records combined into variables
+    sets of PP records combined into variables
 
     '''
-    def __init__(self, path,
-                 byte_ordering = None,
-                 word_size = None,
-                 format = None,
-                 parse = True):        
+    def __init__(self, path, byte_ordering = None, word_size = None,
+                 format = None, parse = True):        
         '''Open and parse a UM file.  The following optional arguments specify
-the file type.  If all three are set, then this forces the file type;
-otherwise, the file type is autodetected and any of them that are set
-are ignored.
-
-:Parmaeters:
-
-    byte_ordering: 'little_endian' or 'big_endian'
-
-    word_size: 4 or 8
-
-    format: 'FF' or 'PP'
-
-The default action is to open the file, store the file type from the
-arguments or autodetection as described above, and then parse the
-contents, giving a tree of variables and records under the File
-object.  However, if "parse = False" is set, then an object is
-returned in which the last step is omitted, so only the file type is
-stored, and there are no variables under it.  Such an object can be
-passed when instantiating Rec objects, and contains sufficient info
-about the file type to ensure that the get_data method of those Rec
-objects will work.
+    the file type. If all three are set, then this forces the file
+    type; otherwise, the file type is autodetected and any of them
+    that are set are ignored.
+    
+    :Parmaeters:
+    
+        byte_ordering: 'little_endian' or 'big_endian'
+    
+        word_size: 4 or 8
+    
+        format: 'FF' or 'PP'
+    
+    The default action is to open the file, store the file type from
+    the arguments or autodetection as described above, and then parse
+    the contents, giving a tree of variables and records under the
+    File object. However, if "parse = False" is set, then an object is
+    returned in which the last step is omitted, so only the file type
+    is stored, and there are no variables under it. Such an object can
+    be passed when instantiating Rec objects, and contains sufficient
+    info about the file type to ensure that the get_data method of
+    those Rec objects will work.
 
         '''
         c = cInterface.CInterface()
@@ -62,23 +61,26 @@ objects will work.
             info = c.parse_file(self.fd, file_type_obj)
             self.vars = info["vars"]
             self._add_back_refs()
-    
+
+            
     def open_fd(self):
-        """
-        (Re)open the low-level file descriptor.
-        """
+        '''(Re)open the low-level file descriptor.
+
+        '''
         if self.fd is None:
             self.fd = os.open(self.path, os.O_RDONLY)
         return self.fd
 
+    
     def close_fd(self):
-        """
-        Close the low-level file descriptor.
-        """
+        '''Close the low-level file descriptor.
+
+        '''
         if self.fd:
             os.close(self.fd)
         self.fd = None
 
+        
     def _detect_file_type(self):
         c = self._c_interface
         try:
@@ -92,58 +94,64 @@ objects will work.
         self.byte_ordering = d["byte_ordering"]
         self.word_size = d["word_size"]
 
+        
     def _add_back_refs(self):
-        """
-        Add file attribute to Var objects, and both file and var attributes
-        to Rec objects.  The important one is the file attribute in the Rec
-        object, as this is used when reading data.  The others are provided
-        for extra convenience.
-        """
+        '''Add file attribute to Var objects, and both file and var
+        attributes to Rec objects.  The important one is the file
+        attribute in the Rec object, as this is used when reading
+        data.  The others are provided for extra convenience.
+
+        '''
         for var in self.vars:
             var.file = self
             for rec in var.recs:
                 rec.var = var
                 rec.file = self
 
+                
+#--- End: class
+
+
 class Var:
-    """
-    container for some information about variables
-    """
+    '''Container for some information about variables
+
+    '''
     def __init__(self, recs, nz, nt, supervar_index=None):
         self.recs = recs
         self.nz = nz
         self.nt = nt
         self.supervar_index = supervar_index
-    
-    def _compare_recs_by_extra_data(self, a, b):
-#        return cmp(a.get_extra_data(),
-#                   b.get_extra_data())
-        x = a.get_extra_data()
-        y = b.get_extra_data()
-        if x == y:
-            return 0
-        elif x > y:
-            return 1
-        else:
-            return -1        
 
-    def _compare_recs_by_orig_order(self, a, b):
-        #        return cmp(self.recs.index(a), self.recs.index(b))
-        x = self.recs.index(a)
-        y = self.recs.index(b)
+        
+    @staticmethod
+    def _compare(x, y):
+        '''Method equivalent to the Python 2 'cmp'. Note that (x > y) - (x <
+    y) is equivalent but not as performant since it would not
+    short-circuit.
+
+        '''
         if x == y:
             return 0
         elif x > y:
             return 1
         else:
             return -1
+
         
+    def _compare_recs_by_extra_data(self, a, b):
+        return self._compare(a.get_extra_data(), b.get_extra_data())
+
+    
+    def _compare_recs_by_orig_order(self, a, b):
+        return self._compare(self.recs.index(a), self.recs.index(b))
+
+    
     def group_records_by_extra_data(self):
         '''Returns a list of (sub)lists of records where each records within
-each sublist has matching extra data (if any), so if the whole
-variable has consistent extra data then the return value will be of
-length 1.  Within each group, the ordering of returned records is the
-same as in self.recs
+    each sublist has matching extra data (if any), so if the whole
+    variable has consistent extra data then the return value will be
+    of length 1.  Within each group, the ordering of returned records
+    is the same as in self.recs
 
         '''
         compare = self._compare_recs_by_extra_data
@@ -169,22 +177,28 @@ same as in self.recs
                 this_grp.sort(key=self._compare_recs_by_orig_order)
                 groups.append(this_grp)
                 this_grp = []
+        #--- End: for
+        
         return groups
 
+    
+#--- End: class
+
+
 class Rec:
-    """
-    container for some information about records
-    """
+    '''Container for some information about records
+
+    '''
     def __init__(self, int_hdr, real_hdr, hdr_offset, data_offset, disk_length, 
                  file = None):
-        """
-        Default instantiation, which stores the supplied headers and offsets.
-        The 'file' argument, used to set the 'file' attribute, does not need
-        to be supplied, but if it is not then it will have to be set on the
-        returned object (to the containing File object) before calling
-        get_data() will work.  Normally this would be done by the calling code
-        instantiating via File rather than directly.
-        """
+        '''Default instantiation, which stores the supplied headers and
+    offsets.  The 'file' argument, used to set the 'file' attribute,
+    does not need to be supplied, but if it is not then it will have
+    to be set on the returned object (to the containing File object)
+    before calling get_data() will work.  Normally this would be done
+    by the calling code instantiating via File rather than directly.
+
+        '''
         self.int_hdr = int_hdr
         self.real_hdr = real_hdr
         self.hdr_offset = hdr_offset
@@ -194,13 +208,14 @@ class Rec:
         if file:
             self.file = file
 
+            
     @classmethod
     def from_file_and_offsets(cls, file, hdr_offset, data_offset, disk_length):
-        """
-        Instantiate a Rec object from the file object and the 
-        header and data offsets.  The headers are read in, and 
-        also the record object is ready for calling get_data().
-        """
+        '''Instantiate a Rec object from the file object and the header and
+    data offsets. The headers are read in, and also the record object
+    is ready for calling get_data().
+
+        '''
         c = file._c_interface
         int_hdr, real_hdr = c.read_header(file.fd,
                                           hdr_offset,
@@ -208,6 +223,7 @@ class Rec:
                                           file.word_size)
         return cls(int_hdr, real_hdr, hdr_offset, data_offset, disk_length, file=file)
 
+    
     def read_extra_data(self):
         '''Read the extra data associated with the record
 
@@ -244,9 +260,9 @@ class Rec:
 
     
     def get_type_and_num_words(self):
-        """get the data type (as numpy type) and number of words as 2-tuple
+        '''Get the data type (as numpy type) and number of words as 2-tuple
 
-        """
+        '''
         c = self.file._c_interface
         ntype, num_words = c.get_type_and_num_words(self.int_hdr)
         if ntype == 'integer':
@@ -257,9 +273,9 @@ class Rec:
 
     
     def get_data(self):
-        """get the data array associated with the record
+        '''Get the data array associated with the record
 
-        """
+        '''
         c = self.file._c_interface
         file = self.file
         data_type, nwords = c.get_type_and_num_words(self.int_hdr)
@@ -274,10 +290,11 @@ class Rec:
                                   data_type, 
                                   nwords)
 
-            
+
+#--- End: class
+
 
 if __name__ == '__main__':
-
     import sys
     
     path = sys.argv[1]
@@ -339,4 +356,3 @@ if __name__ == '__main__':
         for value in rnew.get_data():
             rdata.write("%s\n" % value)
         rdata.close()
-
